
/* Kmostk.cc
 
  Kmostk adj=1 vel=1.5 <infile.H >outfile.H dx=0.025 nx=20

  Applies Kirchhoff operator to dataset, given velocity vel.

  */
 
#include <SEPinit.h>

#include "./fopkmostk.h"

#include <Processnew.h>

main(int argc,char **argv) {
    
	// Seplib initialization
    SepInput * sepInput = SEPinit(argc,argv,SOURCE);

	// Check that we are getting floating point data
    if( sepInput->Info()->Esize() !=4 )
      seperr("esize !=4, expecting floating point data \n");

	// command line arguments
    int adj=0; sepInput->Getch("adj",adj);

    int inv=0; sepInput->Getch("inv",inv);

    int niter=20; sepInput->Getch("niter",niter);

    float ox=0.;   sepInput->Getch("ox",ox);
    int   nx=20;   sepInput->Getch("nx",nx);
    float dx=.025; sepInput->Getch("dx",dx);

    float om=0.;   sepInput->Getch("om",om);
    int   nm=20;   sepInput->Getch("nm",nm);
    float dm=.025; sepInput->Getch("dm",dm);

    float vel=1.5; sepInput->Getch("vel",vel);
    // allow reading from velfile

      	// poststack  Kirchhoff migration/modelling is working on those axes
    Axis t,m,x ;

        // make an input space by reading the data 
    floatspace input(sepInput);

    Axislist inaxlist = input.getaxislist();

    t = inaxlist["Time"];

    if( ( adj==0 && inv==0 ) || ( adj==1 && inv == 1 ) ){ 
      m = inaxlist["mig Midpoint"] ; // midpoint
      Axis xnew(ox,dx,nx,"unmig Midpoint");  // midpoint unmigrated (modelled)
      x = xnew;
    }
    else {
      x = inaxlist["unmig Midpoint"] ; // midpoint unmigrated (modelled)
      Axis mnew(om,dm,nm,"mig Midpoint");      // midpoint migrated
      m = mnew;
    }

	// make KMOstack operator
    fopKMOstk op( t, m, x, 2./vel );

	// Process or Invert data 
    floatspacearray output = Processnew(input,op,adj,inv,niter);

        // write to output
    SepOutput *sepout = new SepOutput("stdout", output(0,0).sepData() );

    delete sepout;
    UnRef(sepInput);

    return 0;
}
