
/* Lmostack.cc
 
  Lmostack adj=1 vel=1.5 < infile.H > outfile.H dx=0.025 nx=20

  Applies LMO stack operator to dataset, given velocity vel.

  */
 
#include <SEPinit.h>
#include <foplmostk.h>
#include <Processnew.h>

main(int argc,char **argv) {
    
	// Seplib initialization
    SepInput * sepInput = SEPinit(argc,argv,SOURCE);

	// Check that we are getting floating point data
    if( sepInput->Info()->Esize() !=4 )
      seperr("esize !=4, expecting floating point data \n");

	// command line arguments
    int adj=0;
    sepInput->Getch("adj",adj);

    int inv=0;
    sepInput->Getch("inv",inv);

    int niter=20; 
    sepInput->Getch("niter",niter);

    int nx=20;
    sepInput->Getch("nx",nx);

    float dx=.025;
    sepInput->Getch("dx",dx);

    float vel=1.5;
    sepInput->Getch("vel",vel);

    Axis t = sepInput->Axis(1);
    Axis x = sepInput->Axis(2);

   if( ( adj==0 && inv==0 ) || ( adj==1 && inv == 1 ) ){ 
	// the forward operation needs an axis length and delta!
      x.length=nx;
      x.delta=dx;
    }
	// make NMOstack operator
    fopLMOstk op(t,x,1./vel);

	// make an input space by reading the data 
    floatspace input(sepInput);

	// Process or Invert data 
    floatspacearray output = Processnew(input,op,adj,inv,niter);

        // write to output
    SepOutput *sepout = new SepOutput("stdout", output(0,0).sepData() );

    delete sepout;
    UnRef(sepInput);

    return 0;
}
