/* Nmostack.cc
 
  Nmostack adj=1 vel=1.5 <infile.H >outfile.H dx=0.025 nx=20

  Applies NMO stack operator to dataset, given velocity vel.

  */
 
#include <SEPinit.h>

#include <fopnmostk.h>

#include <Process.h>

main(int argc,char **argv) {
    
	// Seplib initialization
    SepInput * sepInput = SEPinit(argc,argv,SOURCE);

	// Check that we are getting floating point data
    if( sepInput->Info()->Esize() !=4 )
      seperr("esize !=4, expecting floating point data \n");

	// command line arguments
    int adj=0;
    sepInput->Getch("adj",adj);

    float dx=.025;
    sepInput->Getch("dx",dx);

    int nx=20;
    sepInput->Getch("nx",nx);

    float vel=1.5;
    sepInput->Getch("vel",vel);

    Axis t = sepInput->Axis(1);
    Axis x = sepInput->Axis(2);

    if( !adj ){ // the forward operation needs an axis length and delta!
      x.length=nx;
      x.delta=dx;
    }

	// make NMO
    fopNMOstk op(t,x,1./vel);

	// Process data and output
    Process(sepInput,op,adj);

    UnRef(sepInput);

    return 0;
}
