/* Velan.cc
 
  Velan adj=0 ox=0 dx=.025 nx=20 < infile.H > outfile.H 

  Applies MMO stack modeling operator to dataset, models a range
  of offsets.  offset = ox + i*dx, where i (int) varies from 0 to nx-1.


  Velan adj=1 os=0 ds=.05 ns=20 < infile.H > outfile.H 

  Applies Adjoint MMO stack operator to dataset, for a set of different
  slownesses, slow = so + i*ds, where i (int) varies from 0 to ns-1.

  */
 
#include <SEPinit.h>
#include <fopvelan.h>
#include <Processnew.h>

main(int argc,char **argv) {
    
	// Seplib initialization
    SepInput * sepInput = SEPinit(argc,argv,SOURCE);

	// Check that we are getting floating point data
    if( sepInput->Info()->Esize() !=4 )
      seperr("esize !=4, expecting floating point data \n");

	// command line arguments
    int adj=0;
    sepInput->Getch("adj",adj);

    int inv=0;
    sepInput->Getch("inv",inv);

    int niter=20; 
    sepInput->Getch("niter",niter);

	// axes to define a velan operator
    Axis x,s,t;

	// make an input space by reading the data 
    floatspace input(sepInput);

    Axislist inaxl = input.getaxislist();

    if( ( adj == 0 && inv==0 ) || ( adj==1 && inv == 1 ) ){

    	int nx=20;
    	sepInput->Getch("nx",nx);

    	float dx=.025;
    	sepInput->Getch("dx",dx);

    	float ox=.025;
    	sepInput->Getch("ox",ox);

	Axis newx( ox,dx,nx,"Offset");

	x = newx;
	t = inaxl["Time"];
	s = inaxl["Slowness"];

    }else{


       	int ns=20;			//# of slownesses values
       	sepInput->Getch("ns",ns);

       	float ds=.05;			//slowness step
       	sepInput->Getch("ds",ds);

       	float os=0.;			//initial slowness
       	sepInput->Getch("os",os);

	Axis news(os,ds,ns,"Slowness");

	s = news;
	t = inaxl["Time"];
	x = inaxl["Offset"];

    }
 
	// make Velan operator
    fopVelan op(t, x, s);

	// Process or Invert data 
    floatspacearray output = Processnew(input, op, adj, inv, niter);

        // write to output
    SepOutput *sepout = new SepOutput("stdout", output(0,0).sepData() );

    delete sepout;
    UnRef(sepInput);

    return 0;
}
